pub struct HangulSyllableType(/* private fields */);Expand description
Enumerated property Hangul_Syllable_Type
The Unicode standard provides both precomposed Hangul syllables and conjoining Jamo to compose arbitrary Hangul syllables. This property provides that ontology of Hangul code points.
For more information, see the Unicode Korean FAQ.
Example
use icu::properties::{CodePointMapData, props::HangulSyllableType};
assert_eq!(
CodePointMapData::<HangulSyllableType>::new().get('ᄀ'),
HangulSyllableType::LeadingJamo
); // U+1100
assert_eq!(
CodePointMapData::<HangulSyllableType>::new().get('가'),
HangulSyllableType::LeadingVowelSyllable
); // U+AC00Implementations
Sourceimpl HangulSyllableType
impl HangulSyllableType
pub const NotApplicable: Self
pub const NA: Self = Self::NotApplicable
pub const LeadingJamo: Self
pub const L: Self = Self::LeadingJamo
pub const VowelJamo: Self
pub const V: Self = Self::VowelJamo
pub const TrailingJamo: Self
pub const T: Self = Self::TrailingJamo
pub const LVSyllable: Self
pub const LV: Self = Self::LVSyllable
pub const LVTSyllable: Self
pub const LVT: Self = Self::LVTSyllable
Sourceimpl HangulSyllableType
impl HangulSyllableType
Sourcepub const ALL_VALUES: &'static [Self]
👎Deprecated
pub const ALL_VALUES: &'static [Self]
Deprecated
Sourceimpl HangulSyllableType
impl HangulSyllableType
Sourcepub const LeadingVowelSyllable: Self = Self::LVSyllable
👎Deprecated since 2.3.0: use HangulSyllableType::LVSyllable instead
pub const LeadingVowelSyllable: Self = Self::LVSyllable
use HangulSyllableType::LVSyllable instead
Deprecated: non-canonical spelling
Sourcepub const LeadingVowelTrailingSyllable: Self = Self::LVTSyllable
👎Deprecated since 2.3.0: use HangulSyllableType::LVTSyllable instead
pub const LeadingVowelTrailingSyllable: Self = Self::LVTSyllable
use HangulSyllableType::LVTSyllable instead
Deprecated: non-canonical spelling
Sourcepub const fn to_icu4c_value(self) -> u8
👎Deprecated since 2.3.0: please comment on https://github.com/unicode-org/icu4x/issues/6067 if you need this
pub const fn to_icu4c_value(self) -> u8
please comment on https://github.com/unicode-org/icu4x/issues/6067 if you need this
Returns an ICU4C UHangulSyllableType value.
Sourcepub const fn from_icu4c_value(value: u8) -> Self
👎Deprecated since 2.3.0: please comment on https://github.com/unicode-org/icu4x/issues/6067 if you need this
pub const fn from_icu4c_value(value: u8) -> Self
please comment on https://github.com/unicode-org/icu4x/issues/6067 if you need this
Constructor from an ICU4C UHangulSyllableType value.