pub struct NumericType(/* private fields */);Expand description
Enumerated property Numeric_Type.
See Section 4.6, Numeric Value in The Unicode Standard for the summary of each property value.
Example
use icu::properties::{props::NumericType, CodePointMapData};
assert_eq!(
CodePointMapData::<NumericType>::new().get('0'),
NumericType::Decimal,
); // U+0030
assert_eq!(
CodePointMapData::<NumericType>::new().get('½'),
NumericType::Numeric,
); // U+00BDImplementations
Sourceimpl NumericType
impl NumericType
Sourcepub const fn to_icu4c_value(self) -> u8
pub const fn to_icu4c_value(self) -> u8
Returns an ICU4C UNumericType value.
Sourcepub const fn from_icu4c_value(value: u8) -> Self
pub const fn from_icu4c_value(value: u8) -> Self
Constructor from an ICU4C UNumericType value.
Sourceimpl NumericType
impl NumericType
Sourcepub const None: NumericType
pub const None: NumericType
Characters without numeric value
Sourcepub const Decimal: NumericType
pub const Decimal: NumericType
(De) Characters of positional decimal systems
These are coextensive with GeneralCategory::DecimalNumber.
Sourcepub const Digit: NumericType
pub const Digit: NumericType
(Di) Variants of positional or sequences thereof.
The distinction between NumericType::Digit and NumericType::Numeric
has not proven to be useful, so no further characters will be added to
this type.
Sourcepub const Numeric: NumericType
pub const Numeric: NumericType
(Nu) Other characters with numeric value
Sourcepub const ALL_VALUES: &'static [NumericType]
pub const ALL_VALUES: &'static [NumericType]
All possible values of this enum in the Unicode version from this ICU4X release.