EmojiSet

Trait EmojiSet 

pub trait EmojiSet: Sealed + Sized {
    const NAME: &'static [u8];
    const SHORT_NAME: &'static [u8];

    // Provided methods
    fn for_char(ch: char) -> bool { ... }
    fn for_str(s: &str) -> bool { ... }
}
An Emoji set as defined by Unicode Technical Standard #51.

🚫 This trait is sealed; it cannot be implemented by user code. If an API requests an item that implements this trait, please consider using a type from the implementors listed below.

Required Associated Constants

const NAME: &'static [u8]

The name of this property

const SHORT_NAME: &'static [u8]

The abbreviated name of this property, if it exists, otherwise the name

Provided Methods

fn for_char(ch: char) -> bool

Convenience method for EmojiSetData::new().contains(ch)

✨ Enabled with the compiled_data Cargo feature.

fn for_str(s: &str) -> bool

Convenience method for EmojiSetData::new().contains_str(s)

✨ Enabled with the compiled_data Cargo feature.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl EmojiSet for BasicEmoji

Source

const NAME: &'static [u8]

Source

const SHORT_NAME: &'static [u8]